# blueprintpy

[![Unittest](https://github.com/Enchan1207/blueprintpy/actions/workflows/ci.yml/badge.svg)](https://github.com/Enchan1207/blueprintpy/actions/workflows/ci.yml)
[![version](https://img.shields.io/github/v/release/Enchan1207/blueprintpy)](https://github.com/Enchan1207/blueprintpy/releases)

## Overview

Python パッケージテンプレート展開ユーティリティ

## Description

**blueprintpy**は、Pythonに `swift init` や `npm init` のような パッケージ初期化CLIを提供するユーティリティです。

## Installation

PyPIよりパッケージをインストールできます。インストールの際、同時にCLIツール`blueprint`がインストールされます。

```
pip install blueprintpy
```


## Documents

ドキュメントは[GitHub Pages](https://enchan1207.github.io/blueprintpy/index.html)にて公開しています。
詳細な使用方法やAPIのリファレンスについてはドキュメントをご覧ください。

## License

This repository is published under [MIT License](https://github.com/Enchan1207/blueprintpy/blob/master/LICENSE).
